@@ -1,11 +1,7 @@
 library(pomp)
 
 data(ou2)
-true.p <- c(
-            alpha.1=0.9,alpha.2=0,alpha.3=0,alpha.4=0.99,
-            sigma.1=1,sigma.2=0,sigma.3=2,
-            tau=1,x1.0=50,x2.0=-50
-            )
+true.p <- coef(ou2)
 simdata <- simulate(ou2,nsim=5,params=true.p,seed=394885)
 guess.p <- true.p
 guess.p[grep('sigma',names(guess.p))] <- 0
